@@ -8,12 +8,13 @@ from typing import List, Callable, Dict
 from threading import Thread, Lock
 from threading import current_thread
 
+from msp.message_ids import MessageIDs
+
 from msp.data_structures.analog import Analog
 from msp.data_structures.misc import Misc
 from msp.data_structures.rc_tuning import RCTuning
 from msp.data_structures.wp import WP
-from msp.message_ids import MessageIDs
-from msp.data_structures.channels import Channel
+from msp.data_structures.channels import Channel, ARM_VALUE
 from msp.data_structures.identification import Identification
 from msp.data_structures.status import Status
 from msp.data_structures.motors import Motor
@@ -26,9 +27,6 @@ from msp.data_structures.servos import Servo
 from msp.data_structures.pid_coefficients import PIDCoefficients
 
 
-
-
-
 class MultiWii(Thread):
     """
     MultiWii Protocol Class (MSP) used for interfacing with MSP flight controller boards
@@ -58,7 +56,7 @@ class MultiWii(Thread):
         self.__running = True
 
         #: bool: Determines whether the protocol is armed or not
-        self.__is_armed = False
+        self.is_armed = None
 
         #: Thread safe queue used for receiving feedback from the flight controller
         self.__q = queue.Queue()
@@ -75,8 +73,9 @@ class MultiWii(Thread):
         #: The 2-way serial port used to communicate with the flight controller
         self.__ser = None
         self.__init_comms(ser_port)
+
         self.__rc_actual = Channel()
-        self.rc_target = Channel()
+        self.__rc_target = Channel()
         self.__attitude = Attitude()
         self.__altitude = Altitude()
         self.__imu = IMU()
@@ -108,6 +107,16 @@ class MultiWii(Thread):
         self.__code_action_map = self.__create_action_map()
 
     # Private Methods
+    @property
+    def is_armed(self) -> bool:
+        """Checks to see what the last report from hardware says the value was"""
+        return self.__rc_actual.is_armed()
+
+    @is_armed.setter
+    def is_armed(self, value):
+        """Dummy setter"""
+        pass
+
     def __create_action_map(self) -> Dict:
         """
         Creates an action map between the `MessageIDs <msp.message_ids.html>`_
@@ -216,54 +225,20 @@ class MultiWii(Thread):
         self.__send(MessageIDs.RAW_GPS)
         self.__send(MessageIDs.COMP_GPS)
         self.__send(MessageIDs.PID)
+        self.__send(MessageIDs.MOTOR)
+        self.__send(MessageIDs.ANALOG)
+        self.__send(MessageIDs.RC_TUNING)
+        self.__send(MessageIDs.MISC)
+        self.__send(MessageIDs.WP)
 
-        # Set RC values
-        data = self.rc_target.to_array()
+        # Send RC values
+        data = self.__rc_target.to_array()
         self.__send(
             MessageIDs.SET_RAW_RC,
             len(data)*2,
             data
         )
 
-    def __arm(self) -> None:
-        """
-        Sets the protocol to indicate that it's in an armed state
-
-        :return: None
-        """
-        self.__print("Arming...")
-        self.__rc_actual.armed(True)
-
-        data = self.__rc_actual.to_array()
-        self.__send(
-            MessageIDs.SET_RAW_RC,
-            len(data)*2,
-            data
-        )
-
-        self.__is_armed = True
-        self.__print("Armed")
-
-    def __disarm(self) -> None:
-        """
-        Sets the protocol to indicate that it's in an disarmed state
-
-        :return: None
-        """
-        self.__print("Disarming...")
-        # Roll, Pitch, Throttle, Yaw
-        self.__rc_actual.armed(False)
-
-        data = self.__rc_actual.to_array()
-        self.__send(
-            MessageIDs.SET_RAW_RC,
-            len(data)*2,
-            data
-        )
-
-        self.__is_armed = False
-        self.__print("Disarmed")
-
     def __send(self, code: MessageIDs, data_length=0, data=None) -> None:
         """
         Crafts and sends the command packet to be sent over the serial interface to the Flight Controller.
@@ -371,57 +346,52 @@ class MultiWii(Thread):
             self.__print("Closing Serial Port")
             self.__ser.close()
 
-    def is_armed(self) -> bool:
-        """
-        Returns whether the protocol is armed or not
-
-        :return: Whether the protocol has been armed or not.
-        """
-        return self.__is_armed
-
-    def arm(self) -> None:
-        """
-        Arms the protocol
-
-        :return: None
-        """
-        self.__on_thread(self.__arm)
-
-    def disarm(self) -> None:
-        """
-        Disarms the protocol
-
-        :return: None
-        """
-        self.__on_thread(self.__disarm)
-
     def calibrate_acc(self):
         self.__on_thread(self.__send, [MessageIDs.ACC_CALIBRATION, []])
 
     # Setters
-    def set_target_channels(self, channel):
-        self.rc_target = channel
+    def set_roll(self, value: float):
+        """Gets the current roll value"""
+        self.__rc_target.roll = value
 
-    # Getters
-    def get_imu(self):
-        return self.__imu.to_array()
+    def set_pitch(self, value: float):
+        """Gets the current pitch value"""
+        self.__rc_target.pitch = value
 
-    def get_attitude(self):
-        return self.__attitude.to_array()
+    def set_yaw(self, value: float):
+        """Gets the current yaw value"""
+        self.__rc_target.yaw = value
 
-    def get_altitude(self):
-        return self.__altitude.to_array()
+    def set_throttle(self, value: float):
+        """Gets the current throttle value"""
+        self.__rc_target.throttle = value
 
-    def get_rc_channels(self):
-        return self.__rc_actual.to_array()
+    def arm(self):
+        """Arms the protocol"""
+        self.__print("Arming...")
+        self.__rc_target.arm()
 
-    def get_gps(self):
-        return self.__gps.to_array()
+    def disarm(self):
+        """Disarms the protocol"""
+        self.__print("Disarming...")
+        self.__rc_target.disarm()
 
-    def get_comp_gps(self):
-        return self.__comp_gps.to_array()
+    def set_mma_values(self, values: List[int]):
+        self.set_roll(values[0])
+        self.set_pitch(values[1])
+        self.set_yaw(values[2])
+        self.set_throttle(values[3])
+        if len(values) > 4:
+            if values[4] == ARM_VALUE:
+                self.arm()
+            else:
+                self.disarm()
 
-    def get_pid(self):
-        return self.pid_coef.to_array()
+    def get_pos(self) -> List[float]:
+        return [self.__gps.lat, self.__gps.lon]
 
+    def get_heading(self) -> int:
+        return self.__attitude.heading
 
+    def get_altitude(self) -> float:
+        return self.__gps.altitude
